@@ -7,7 +7,7 @@ import (
 	"time"
 
 	"github.com/clarketm/json"
-	ign3types "github.com/coreos/ignition/v2/config/v3_1/types"
+	ign3types "github.com/coreos/ignition/v2/config/v3_2/types"
 	configv1 "github.com/openshift/api/config/v1"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -26,8 +26,10 @@ import (
 
 	mcfgv1 "github.com/openshift/machine-config-operator/pkg/apis/machineconfiguration.openshift.io/v1"
 	ctrlcommon "github.com/openshift/machine-config-operator/pkg/controller/common"
+	daemonconsts "github.com/openshift/machine-config-operator/pkg/daemon/constants"
 	"github.com/openshift/machine-config-operator/pkg/generated/clientset/versioned/fake"
 	informers "github.com/openshift/machine-config-operator/pkg/generated/informers/externalversions"
+	"github.com/openshift/machine-config-operator/pkg/version"
 	"github.com/openshift/machine-config-operator/test/helpers"
 )
 
@@ -222,7 +224,7 @@ func (f *fixture) expectUpdateMachineConfigPoolStatus(pool *mcfgv1.MachineConfig
 func newControllerConfig(name string) *mcfgv1.ControllerConfig {
 	return &mcfgv1.ControllerConfig{
 		TypeMeta:   metav1.TypeMeta{APIVersion: mcfgv1.SchemeGroupVersion.String()},
-		ObjectMeta: metav1.ObjectMeta{Name: name, UID: types.UID(utilrand.String(5))},
+		ObjectMeta: metav1.ObjectMeta{Annotations: map[string]string{daemonconsts.GeneratedByVersionAnnotationKey: version.Raw}, Name: name, UID: types.UID(utilrand.String(5))},
 		Spec: mcfgv1.ControllerConfigSpec{
 			Infra: &configv1.Infrastructure{
 				Status: configv1.InfrastructureStatus{
@@ -384,6 +386,25 @@ func TestGenerateMachineConfigNoOverrideOSImageURL(t *testing.T) {
 	assert.Equal(t, "dummy", gmc.Spec.OSImageURL)
 }
 
+func TestVersionSkew(t *testing.T) {
+	mcp := helpers.NewMachineConfigPool("test-cluster-master", helpers.MasterSelector, nil, "")
+	mcs := []*mcfgv1.MachineConfig{
+		helpers.NewMachineConfig("00-test-cluster-master", map[string]string{"node-role/master": ""}, "dummy-test-1", []ign3types.File{}),
+		helpers.NewMachineConfig("00-test-cluster-master-0", map[string]string{"node-role/master": ""}, "dummy-change", []ign3types.File{}),
+	}
+
+	cc := newControllerConfig(ctrlcommon.ControllerConfigName)
+	cc.Annotations[daemonconsts.GeneratedByVersionAnnotationKey] = "different-version"
+	_, err := generateRenderedMachineConfig(mcp, mcs, cc)
+	require.NotNil(t, err)
+
+	// Now the same thing without overriding the version
+	cc = newControllerConfig(ctrlcommon.ControllerConfigName)
+	gmc, err := generateRenderedMachineConfig(mcp, mcs, cc)
+	require.Nil(t, err)
+	require.NotNil(t, gmc)
+}
+
 func TestDoNothing(t *testing.T) {
 	f := newFixture(t)
 	mcp := helpers.NewMachineConfigPool("test-cluster-master", helpers.MasterSelector, nil, "")
